#
# spec file for package fips
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fips
Version:        3.4.0
Release:        1.15
Summary:        OpenGL-based FITS image viewer
License:        LGPL-3.0-only
Group:          Productivity/Scientific/Astronomy
URL:            https://github.com/matwey/fips3
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake >= 3.0
BuildRequires:  gcc-c++
BuildRequires:  libQt5Gui-devel
BuildRequires:  libQt5Test-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  make
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FIPS is a cross-platform FITS viewer with responsive user interface. Unlike
other FITS viewers FIPS uses GPU hardware via OpenGL to provide usual
functionality such as zooming, panning and level adjustments. OpenGL 2.1 and
later is supported.

FIPS supports all 2D image formats except of 64-bit floating point numbers
(BITPIX=-64). FITS image extension has basic limited support.

%prep
%setup -q

%build
%cmake
%make_jobs

%install
%cmake_install
%suse_update_desktop_file -i space.fips.Fips

%check
%ctest

%files
%doc README.md
%license LICENSE.txt
%{_bindir}/%{name}
%{_datadir}/applications/space.fips.Fips.desktop
%{_datadir}/metainfo/space.fips.Fips.metainfo.xml
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/128x128/apps
%{_datadir}/icons/hicolor/128x128/apps/space.fips.Fips.png
%dir %{_datadir}/icons/hicolor/256x256
%dir %{_datadir}/icons/hicolor/256x256/apps
%{_datadir}/icons/hicolor/256x256/apps/space.fips.Fips.png
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/space.fips.Fips.svg

%changelog
* Sat May  2 2020 matwey.kornilov@gmail.com
- Update to version 3.4.0:
  * Version 3.4.0
  * Drop uninstaller link (#115)
  * Add dist/freedesktop/space.fips.Fips.metainfo.xml
  * Block installation on Windows earlier than 7 SP1 (#115)
  * Migrate installer to WiX (#115)
  * VS2019 compatibility
  * Add Fedora to README.md
  * Reimplement fit to window
  * Implement image panning via left-button dragging
  * Pass QEvent::MouseMove to OpenGLWidget
  * Move MouseMoveEventFilter out of global namespace
  * Drop Viewrect::setWidget()
  * Drop view rect from Viewrect
  * Drop view rect from OpenGLWidget
  * Drop view rect from OpenGLTransform
  * Introduce OpenGLTransform::setWidgetSize()
  * Reimplement ScrollArea using virtual position and size
  * Handle zoom in QOpenGLWidget
  * Handle image aspect ratio in OpenGLTransform
  * Add up-to-date compilers to .travis.yml
  * Do not show open file dialog when drop broken file on Dock
  * Check that at least one instance is started correctly
  * Add initial implementation for the playback single-shot mode
  * Initial playback interval control
  * Initial implementation for *OpenGL30ArrayPlan (OpenGL 3.0+)
  * Initial implementation for *OpenGLArrayPlan (OpenGL 2.1)
  * Add playback test data
  * Initial implementation for 3D FITS file reading
  * Add Playback to MainWindow
  * Initial implementation for PlaybackWidget
  * Initial implementation for Playback
  * Add layer getter and setter for OpenGLWidget
  * Add layer number for HDUValueGetter
  * Introduce AbstractOpenGLPlan::hdu()
  * Introduce AbstractOpenGLPlan::imageTexture() const
  * Initial implementation for *OpenGL33ArrayPlan
  * Add implementation for OpenGLShaderProgram::setLayerUniform()
  * Add initial implementation for *OpenGL*TextureArray
  * Allow setting texture target in AbstractOpenGLTexture constructor
  * Introduce AbstractOpenGLTexture::setData()
  * Introduce AbstractOpenGLTexture::setSize()
  * Introduce FITS::ImageDataUnit::depth()
  * Do not fail Travis build when transfer.sh is down
  * Use xenial in .travis.yml
  * Add docks actions to View menu
  * than -> then
  * Spelling
  * Drag and drop files
  * Remove {{ from README for Github Pages
  * Add bibtex for Astronomy and Computing paper
  * Revert "Set macOS build target to 10.12"
  * Introduce HeaderUnit::count()
  * Add Qt 5.12
  * Upload every macOS build to transfer.sh
  * macOS 10.13 is required by Qt 5.12
  * Set macOS build target to 10.12
  * Implented FITS headers viewer
  * Use header_as() in AbstractDataUnit::createFromPages()
  * Make header_as<T>(key, default) behaviour consistent
  * Disable Travis services for osx
  * Cache brew dirs in Travis
  * Switch to minimal Travis image
  * Added quotation marks in CMakeLists
  * fips accepted to openSUSE Leap 15.1
  * Add ASCL badge
  * README.md: Fips accepted to openSUSE
  * Fix OpenGLWidget::pixelFromWidgetCoordinate() on big-endian systems
  * Fix setSwapBytesEnabled argument value for *OpenGLTexture
  * Add misc links to README.md
  * Add FlatPak to README.md
* Sat Mar  9 2019 Matwey V. Kornilov <matwey.kornilov@gmail.com>
- Drop %%defattr
- Use %%license for LICENSE.txt
* Tue Mar  5 2019 opensuse-packaging@opensuse.org
- Update to version 3.3.1:
  * Version 3.3.1
  * Fix Exception::what()
  * Do not crash app when broken file is dropped via macOS Dock
  * Remove using Utils::swap_bytes
  * Fix makeMinMax() for images with NaNs
  * Utils::min and max adaptive to NaN
* Fri Aug 10 2018 opensuse-packaging@opensuse.org
- Update to version 3.3.0:
  * Version 3.3.0
  * Fix GhPages: show .screenshot on the site
  * Add screenshot
  * Rename desktop file and icons to reverse DNS style
  * Update README.md
  * RPM packages for openSUSE in science repo now
  * Initial implementation for DoubleOpenGL30Plan
  * Initial implementation for FloatOpenGL30Plan
  * Add initial implementation for Int32OpenGL30Plan
  * Initial implementation for Int16OpenGL30Plan
  * Add initial implementation for Uint8OpenGL30Plan
  * Introduce AbstractOpenGLPlanTexture template class
  * Rename *OpenGL33Plan: *-opengl3 to *-opengl3.3
  * Add const qualifier to AbstractOpenGLPlane::*ShaderSourceCode()
  * Drop QObject from AbstractOpenGLPlan
  * Add support of BITPIX=-64
  * BITPIX=-32 for OpenGL 3.3
  * BITPIX=64 for OpenGL 3.3
  * BITPIX=32 for OpenGL 3.3
  * BITPIX=16 support for OpenGL 3.3
  * BITPIX=8 for openGL >= 3.3
  * Use HTML &copy; instead of unicode symbol
  * Make home page URL clickable
  * Add using OpenGLPlan name to the About dialog
  * Add Qt version to the About dialog
  * Add fips version to the About dialog
  * Reimplement AbstractOpenGLPlan::draw() both for VAO supported and unsupported cases
  * Add initial implementation for AbstractOpenGLPlan::draw()
  * Drop unused signals from OpenGLPlane
  * Do not set OpenGL 3.0 and OpenGL 2.1 flags for OpenGL 3.3
  * Set XDG_PREFIX according to CMAKE_INSTALL_PREFIX
  * Drop XDG_DATA_DIRS from find_path XDG_PREFIX
  * Return number of opened files from openFile()
  * Add Qt version status message for CMakeLists.txt
  * Update .travis.yml
  * Drop unused #include <QDebug>
  * Fix uninitialized variable in OpenGLFeatures
  * Use OpenGLPlanFactory in OpenGLWidget
  * Add initial implementation for OpenGLPlanFactory
  * Add initial implementation for resolveOpenGLPlan
  * Add initial implementation for *OpenGLPlan::satisfied()
  * Add initial implementation for OpenGLFeatures and OpenGLRequiredFeatures
  * Reword OpenGL context version requirement
  * Move hduMinMax() and insturmentalMinMax() from OpenGLTexture to OpenGLPlan
  * Add initial implementation AbstractOpenGLPlan::initialize()
  * Add initial implementation for OpenGLWidget::PlanInitializationError
  * Move OpenGLPlane to AbstractOpenGLPlan
  * Move OpenGLTexture to AbstractOpenGLPlan
  * Add initial implementation for AbstractOpenGLPlan::vertexShaderSourceCode()
  * Add initial implementation for AbstractOpenGLPlan::fragmentShaderSourceCode()
  * Add initial implementation for OpenGLWidget::PlanCreationError
  * Add implementation for AbstractOpenGLPlan::name()
  * Add initial implementation for AbstractOpenGLPlan
  * Add GitHub PR template
  * Drop redundant texture unbinding
  * Add setMVPUniform(), setCUniform(), setZUniform() helpers for OpenGLShaderProgram
  * Drop redundant texture binding from initializeGLObjects()
  * Refactor OpenGLTexture
  * Add implementation for FITSToInstrumental() and InstrumentalToFITS()
  * Add implementation for AbstractHeaderDataUnit::apply()
  * Refactor FITS::HeaderDataUnit
  * Refactor FITS::AbstractDataUnit hierarchy
  * Refactor FITS::HeaderUnit
  * Simplify DataUnitCreateHelper
  * Allow returning data from FITS::AbstractDataUnit::bitpixToType()
  * Drop extra setAttributeArray from paintGL()
  * Move uv_data to OpenGLPlane
  * Add initial implementation for OpenGLShaderProgram
  * Reimplement OpenGLWidget::initializeGLObjects::ShaderLoader to return shader string directly
  * Add support for returning data from AbstractDataUnit::apply() function
  * Add initial implementation for Utils::Result<>
* Tue Jun 26 2018 opensuse-packaging@opensuse.org
- Update to version 3.2.3:
  * Version 3.2.3
  * Fix ScientificSpinBox text edition
  * Wrap in initializeGLObjects in setHDU by {make,done}Current()
  * Fix issue with level spin boxes for small absolute values
  * Fix MacOS build
* Sat Nov 18 2017 opensuse-packaging@opensuse.org
- Update to version 3.2.2:
  * Fix WidgetToFitsOpenGLTransform in vertical direction
  * Verson 3.2.2
* Tue Nov 14 2017 opensuse-packaging@opensuse.org
- Update to version 3.2.1:
  * Remove dock widget shortcuts
  * Redo TestOpenGLPlane
  * Version 3.2.1
* Mon Nov 13 2017 opensuse-packaging@opensuse.org
- Update to version 3.2.0:
  * Editorial changes in README.md
  * Initial implementation of scientific spin boxes
  * Update README.md
  * Use locale settings for spin box text
  * Override "step by" logic for scientific spin box
  * Set linear step for ScientificSpinBox
  * Changes for @matwey's review
  * Use raw pointers for spinbox_ and slider_
  * Use raw pointers for min_level_ and max_level_
  * Use raw pointers for button_group_
  * Do deploy not only from master
  * Add clang 4 to .travis.yml
  * Put Utils::row_align into separate module
  * Reimplement Utils::row_align in a platform-independ way
  * Put byte swapping routines to separate module
  * Fix MS Visual Studio build
  * Drop cmake target INSTALL from .appveyor.yml
  * Add document icon and include it into macOS bundle
  * Set binary git attribute for icon files
  * Use mouse wheel for zoom in and zoom out
  * Prototypes of refresh and open in window actions
  * Use right macOS bundle location
  * Refactor OpenGLWidget
  * Reimplement FITS replacement via texture reloading
  * Use Release build type for Linux in .travis.yml
  * Use -Wall in .travis.yml
  * Fix -Wsign-compare in src/colormapwidget.cpp
  * Let compilers be extra verbose and pedantic
  * Fix extra ';'
  * Fix unused parameter 'pos' in src/levelswidget.cpp
  * Move Exception to Utils::Exception
  * Implement Utils::Optional<T>
  * Initial implementation of status bar
  * Align text in status bar
  * Add autorefresh
  * Return missed window title
  * Do not use VBO for vertex and UV data
  * Move spinbox classes to separate files
  * Add rotation dock widget
  * Add initial implementation for AbstractOpenGLTransform
  * Add initial implementation for OpenGLTransform and WidgetToFitsOpenGLTransform
  * Use OpenGLTransform in OpenGLWidget
  * Add initial implementation for OpenGLPlane
  * Update to MacOS 10.11
  * Use OpenGLPlane instead of VertexCoordinates
  * Drop class OpenGLWidget::VertexCoordinates
  * Fix OpenGLPlane::planeRect()
  * Fix Fit to Window for rotated image
  * Initial implementation of level buttons
  * Replace strange button with cool check box
  * Add unit test for OpenGLPlane
  * Add unit test for WidgetToFitsOpenGLTransform
  * Use QTEST_GUILESS_MAIN instead of QTEST_MAIN
  * Drop unused #include <QDebug>
  * Fix const type qualifier on return type has no effect
  * Fix initialization order warning in rotationwidget
  * Fix unused parameter 'pos' warning
  * Fix unused parameter 'max' warning
  * Fix signed/unsigned comparison mismatch warning
  * Hold viewrect center during rotation
  * Initial implementation for FlipWidget
  * Initial implementation of flipping
  * Hold viewrect center while flipping
  * Bump CMakeLists.txt version to 3.2.0
* Thu Aug 24 2017 opensuse-packaging@opensuse.org
- Update to version 3.1.1:
  + Fix issue with row alignment
  + Version 3.1.1
* Mon Aug 21 2017 matwey.kornilov@gmail.com
- Version 3.1.0
* Mon Aug 21 2017 opensuse-packaging@opensuse.org
- Update to version 3.1.0:
  * Deploy .dmg to GitHub Releases
  * Use correct directive WORKING_DIRECTORY instead of WORKING_DIR
  * Add Copyrigth info in appropriate places
  * Windows: prepare installers using NSIS
  * Add artifact deployment for appveyor
* Sat Aug 19 2017 opensuse-packaging@opensuse.org
- Update to version 3.0.0+git20170818.4c649ce:
  * Show file selection dialog when opened without arguments
  * Add initial .appveyor.yml
  * Add Appveyor badge to README.md
  * Allow building fips for all platforms
  * Use MSVS specific byte-swapping routines
  * Define vbo_data[] as const GLfloat
  * Add Debug and Release build targets to .appveyor.yml
  * Emit pixelViewrectChanged (e.g. update bars) before redraw image
  * Add initial implementation for Application
  * Move startup logic to Application
  * Initial implementation for Instance
  * Create DMG via CPack
  * Add supported file types to Info.plist
  * Remove GLSL version specifier
  * Add file->open action
  * Fix QT URL in README.md
  * Check required Qt5 version in CMakeLists.txt
  * Use tabs instead of spaces in CMakeLists.txt
  * Allow multiple positional arguments in command line
  * Fix fit to window (again)
  * Adapt GLSL code to OpenGL ES
  * Drop setRenderableType(QSurfaceFormat::OpenGLES)
  * Add License to DMG
  * Add support of MacOS native file open event
  * Show file dialog on Mac on startup only if there are no files to look at
  * Add new menu bar actions
  * Add icon fot unpacked DMG
  * Use default package name
  * Implement color maps via 1D textures
  * Add gradient.fits test file
  * Move color value adjustment from shaders to OpenGLShaderUniforms
* Fri Aug 11 2017 opensuse-packaging@opensuse.org
- Update to version 3.0.0+git20170811.1d6ec33:
  * Return minimum and maximum values on big endian platform
  * Use correct initialization order in Visitor
* Fri Aug 11 2017 opensuse-packaging@opensuse.org
- Update to version 3.0.0+git20170811.6bfa07d:
  * Create LICENSE
  * Add level sliders (#14)
  * Do not swap bytes on big-endian systems
  * Add Palette Switcher (#15)
  * Add README.md
  * Set theme jekyll-theme-cayman
  * Create CNAME
  * Merge branch 'zoom' into master
  * Support of MacOS .app and .dmg building
  * Add version into Info.plist
  * Overwrite existing .dmg
* Thu Aug 10 2017 matwey.kornilov@gmail.com
- Initial version
